Documentation
¶
Overview ¶
Package flight_server provides a Flight server for handling Arrow record batches.
Index ¶
- type FlightServer
- func (s *FlightServer) DeleteBatch(batchID string) bool
- func (s *FlightServer) DoGet(request *flight.Ticket, stream flight.FlightService_DoGetServer) error
- func (s *FlightServer) DoPut(stream flight.FlightService_DoPutServer) error
- func (s *FlightServer) GetFlightInfo(ctx context.Context, request *flight.FlightDescriptor) (*flight.FlightInfo, error)
- func (s *FlightServer) HasBatch(batchID string) bool
- func (s *FlightServer) ListBatches() []string
- func (s *FlightServer) Start() error
- func (s *FlightServer) Stop()
- func (s *FlightServer) UpdateBatchTTL(batchID string, ttl time.Duration) bool
- type ServerConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FlightServer ¶
type FlightServer struct {
flight.BaseFlightServer
// contains filtered or unexported fields
}
FlightServer implements a simple Arrow Flight server for sharing Arrow RecordBatches between services with minimal serialization.
func NewFlightServer ¶
func NewFlightServer(config ServerConfig) (*FlightServer, error)
NewFlightServer creates a new Arrow Flight server
func (*FlightServer) DeleteBatch ¶
func (s *FlightServer) DeleteBatch(batchID string) bool
DeleteBatch deletes a batch from the server
func (*FlightServer) DoGet ¶
func (s *FlightServer) DoGet(request *flight.Ticket, stream flight.FlightService_DoGetServer) error
DoGet implements the Flight DoGet method
func (*FlightServer) DoPut ¶
func (s *FlightServer) DoPut(stream flight.FlightService_DoPutServer) error
DoPut implements the Flight DoPut method
func (*FlightServer) GetFlightInfo ¶
func (s *FlightServer) GetFlightInfo(ctx context.Context, request *flight.FlightDescriptor) (*flight.FlightInfo, error)
GetFlightInfo implements the Flight GetFlightInfo method
func (*FlightServer) HasBatch ¶
func (s *FlightServer) HasBatch(batchID string) bool
HasBatch checks if a batch exists in the server
func (*FlightServer) ListBatches ¶
func (s *FlightServer) ListBatches() []string
ListBatches returns the IDs of all stored batches
func (*FlightServer) UpdateBatchTTL ¶
func (s *FlightServer) UpdateBatchTTL(batchID string, ttl time.Duration) bool
UpdateBatchTTL updates the expiration time for a batch
Click to show internal directories.
Click to hide internal directories.